==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Sketcher/Gui/TaskDlgEditSketch.h <==
/***************************************************************************
 *   Copyright (c) 2009 Jrgen Riegel <juergen.riegel@web.de>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef SKETCHERGUI_TaskDlgEditSketch_H
#define SKETCHERGUI_TaskDlgEditSketch_H

#include <Gui/TaskView/TaskDialog.h>

#include "ViewProviderSketch.h"
#include "TaskSketcherConstrains.h"
#include "TaskSketcherGeneral.h"

namespace SketcherGui {


/// simulation dialog for the TaskView
class SketcherGuiExport TaskDlgEditSketch : public Gui::TaskView::TaskDialog
{
    Q_OBJECT

public:
    TaskDlgEditSketch(ViewProviderSketch *sketchView);
    ~TaskDlgEditSketch();
    ViewProviderSketch* getSketchView() const
    { return sketchView; }

public:
    /// is called the TaskView when the dialog is opened
    virtual void open();
    /// is called by the framework if an button is clicked which has no accept or reject role
    virtual void clicked(int);
    /// is called by the framework if the dialog is accepted (Ok)
    virtual bool accept();
    /// is called by the framework if the dialog is rejected (Cancel)
    virtual bool reject();
    /// is called by the framework if the user presses the help button 
    virtual void helpRequested();

    /// returns for Close and Help button 
    virtual QDialogButtonBox::StandardButtons getStandardButtons(void) const
    { return QDialogButtonBox::Close|QDialogButtonBox::Help; }

protected:
    ViewProviderSketch   *sketchView;

    TaskSketcherConstrains  *Constraints;
    TaskSketcherGeneral     *General;

};



} //namespace RobotGui

#endif // SKETCHERGUI_TaskDlgEditSketch_H

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Sketcher/Gui/TaskDlgEditSketch.h <==
/***************************************************************************
 *   Copyright (c) 2009 Jrgen Riegel <juergen.riegel@web.de>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef SKETCHERGUI_TaskDlgEditSketch_H
#define SKETCHERGUI_TaskDlgEditSketch_H

#include <Gui/TaskView/TaskDialog.h>

#include "ViewProviderSketch.h"
#include "TaskSketcherConstrains.h"
#include "TaskSketcherGeneral.h"
#include "TaskSketcherMessages.h"

namespace SketcherGui {


/// simulation dialog for the TaskView
class SketcherGuiExport TaskDlgEditSketch : public Gui::TaskView::TaskDialog
{
    Q_OBJECT

public:
    TaskDlgEditSketch(ViewProviderSketch *sketchView);
    ~TaskDlgEditSketch();
    ViewProviderSketch* getSketchView() const
    { return sketchView; }

public:
    /// is called the TaskView when the dialog is opened
    virtual void open();
    /// is called by the framework if an button is clicked which has no accept or reject role
    virtual void clicked(int);
    /// is called by the framework if the dialog is accepted (Ok)
    virtual bool accept();
    /// is called by the framework if the dialog is rejected (Cancel)
    virtual bool reject();
    /// is called by the framework if the user presses the help button 
    virtual void helpRequested();
    virtual bool isAllowedAlterDocument(void) const
    { return false; }

    /// returns for Close and Help button 
    virtual QDialogButtonBox::StandardButtons getStandardButtons(void) const
    { return QDialogButtonBox::Close|QDialogButtonBox::Help; }

protected:
    ViewProviderSketch   *sketchView;

    TaskSketcherConstrains  *Constraints;
    TaskSketcherGeneral     *General;
    TaskSketcherMessages    *Messages;
};



} //namespace SketcherGui

#endif // SKETCHERGUI_TaskDlgEditSketch_H
